#!/usr/bin/env python
# coding: utf-8

# In this example, we cluster our alanine dipeptide trajectory using the [RMSD distance metric](http://en.wikipedia.org/wiki/Root-mean-square_deviation_of_atomic_positions) and [hierarchical clustering](https://en.wikipedia.org/wiki/Hierarchical_clustering).

# In[ ]:


from __future__ import print_function
get_ipython().run_line_magic('matplotlib', 'inline')
import mdtraj as md
import numpy as np
import matplotlib.pyplot as plt
import scipy.cluster.hierarchy
from scipy.spatial.distance import squareform


# Let's load up our trajectory. This is the trajectory that we generated in the "Running a simulation in OpenMM and analyzing the results with mdtraj" example. The first step is to build the rmsd cache, which precalculates some values for the RMSD computation.

# In[ ]:


traj = md.load('ala2.h5')


# Lets compute all pairwise rmsds between conformations.

# In[ ]:


distances = np.empty((traj.n_frames, traj.n_frames))
for i in range(traj.n_frames):
    distances[i] = md.rmsd(traj, traj, i)
print('Max pairwise rmsd: %f nm' % np.max(distances))


# `scipy.cluster` implements the average linkage algorithm (among others)

# In[ ]:


# Clustering only accepts reduced form. Squareform's checks are too stringent
assert np.all(distances - distances.T < 1e-6)
reduced_distances = squareform(distances, checks=False)


# In[ ]:


linkage = scipy.cluster.hierarchy.linkage(reduced_distances, method='average')


# Lets plot the resulting dendrogram.

# In[ ]:


plt.title('RMSD Average linkage hierarchical clustering')
_ = scipy.cluster.hierarchy.dendrogram(linkage, no_labels=True, count_sort='descendent')

